import type { Rule } from "eslint";

const rule: Rule.RuleModule = {
  meta: {
    type: "problem",
    docs: {
      description: "Disallow importing webcrypto from node:crypto and crypto modules",
      category: "Best Practices",
      recommended: true,
    },
    schema: [],
  },
  create: context => ({
    ImportDeclaration(node) {
      const importedSource = node.source.value as string;
      const importedSpecifier = node.specifiers[0];

      if (
        (importedSource === "crypto" || importedSource === "node:crypto") &&
        importedSpecifier.type === "ImportSpecifier" &&
        importedSpecifier.local.name === "webcrypto"
      ) {
        context.report({
          node: importedSpecifier,
          message:
            "Do not import 'webcrypto' from 'crypto' or 'node:crypto'. Use the global variable 'crypto' instead.",
        });
      }
    },
  }),
};

export default rule;
